@@ -1,3 +1,19 @@
+/**********************************************************************
+*   This file is part of Search and Rescue II (SaR2).                 *
+*                                                                     *
+*   SaR2 is free software: you can redistribute it and/or modify      *
+*   it under the terms of the GNU General Public License v.2 as       *
+*   published by the Free Software Foundation.                        *
+*                                                                     *
+*   SaR2 is distributed in the hope that it will be useful, but       *
+*   WITHOUT ANY WARRANTY; without even the implied warranty of        *
+*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See          *
+*   the GNU General Public License for more details.                  *
+*                                                                     *
+*   You should have received a copy of the GNU General Public License *
+*   along with SaR2.  If not, see <http://www.gnu.org/licenses/>.     *
+***********************************************************************/
+
 /*
 			       Game Controller
  */
@@ -5,6 +21,7 @@
 #ifndef GCTL_H
 #define GCTL_H
 
+#include <SDL/SDL.h>
 #include <sys/types.h>
 #include "gw.h"
 
@@ -321,7 +338,9 @@ typedef struct {
 
 	/* Each structure reffers to a joystick */
 	gctl_js_struct	*joystick;
-	int		total_joysticks;
+    int		total_joysticks;
+    /* we add a an array for SDL joystick here. */
+    SDL_Joystick **sdljoystick;
 
 } gctl_struct;
 #define GCTL(p)		((gctl_struct *)(p))
