@@ -7,12 +7,11 @@
 
 extern v3d_texture_ref_struct *SARCreateHorizonTexture(
         const char *name,
-        sar_color_struct *start_color,  /* Top. */
-        sar_color_struct *end_color,    /* Bottom. */
+	const sar_color_struct *start_color,	/* Top color */
+	const sar_color_struct *end_color,	/* Bottom color */
         int height,
-        double midpoint
+	float midpoint
 );
 
 
-
 #endif	/* HORIZON_H */
