@@ -1,7 +1,3 @@
-/*
-                       SAR Scene Messages Management
- */
-
 #ifndef MESSAGES_H
 #define MESSAGES_H
 
