@@ -1,5 +1,5 @@
 /*
- *                          Music File Referance List IO
+ *                       Music File Reference List IO
  */
 #ifndef MUSICLISTIO_H
 #define MUSICLISTIO_H
@@ -9,40 +9,35 @@
 
 
 /*
- *	Music file referance flags:
+ *	Music Reference Flags:
  */
 #define SAR_MUSIC_REF_FLAGS_REPEAT	(1 << 1)
 #define SAR_MUSIC_REF_FLAGS_FADE_IN	(1 << 2)
 #define SAR_MUSIC_REF_FLAGS_FADE_OUT	(1 << 3)
 
 /*
- *	Music file referance structure:
+ *	Music Reference:
  */
 typedef struct {
 
-	char *name;		/* Referance name. */
-	char *filename;
-
-	unsigned int flags;	/* Any of SAR_MUSIC_REF_FLAGS_*. */
-
-	/* Referance name of next music to be played if this one does
-	 * not repeat (NULL for none).
-	 */
-	char *next_name;
+	int		id;		/* One of SAR_MUSIC_ID_* */
+	char		*filename;
+	unsigned int	flags;		/* Any of SAR_MUSIC_REF_FLAGS_* */
 
 } sar_music_ref_struct;
+#define SAR_MUSIC_REF(p)	((sar_music_ref_struct *)(p))
 
 
-extern sar_music_ref_struct *SARMusicMatch(
+extern sar_music_ref_struct *SARMusicMatchPtr(
 	sar_music_ref_struct **ml, int total,
-	int ref_code
+	int id, int *music_ref_num
 );
 
 extern void SARMusicListDeleteAll(
-        sar_music_ref_struct ***ml, int *total
+	sar_music_ref_struct ***ml, int *total
 );
 extern int SARMusicListLoadFromFile(
-        const char *filename,
+	const char *filename,
 	sar_music_ref_struct ***ml, int *total
 );
 
