@@ -1406,6 +1406,7 @@ static void SARKeyEngine(SAR_KEY_FUNC_PROTOTYPE)
 	sar_object_struct *obj_ptr;
 	sar_object_aircraft_struct *aircraft;
 	sar_option_struct *opt = &core_ptr->option;
+        static int used_to_be_engine_sound = False;
 
 	if((scene == NULL) || !state)
 	    return;
@@ -1429,6 +1430,20 @@ static void SARKeyEngine(SAR_KEY_FUNC_PROTOTYPE)
 		    core_ptr->recorder, opt->event_sounds,
 		    SAR_IS_EAR_IN_COCKPIT(scene)
 		);
+                /* turn off engine sound */
+                if (opt->engine_sounds == True)
+                   used_to_be_engine_sound = True;
+                else
+                   used_to_be_engine_sound = False;
+                opt->engine_sounds = False;
+                SARSceneSoundUpdate(
+                   core_ptr,
+                   opt->engine_sounds,
+                   opt->event_sounds,
+                   opt->voice_sounds,
+                   opt->music
+                 );
+                
 	    }
 	    else if(!display->shift_key_state)
 	    {
@@ -1439,6 +1454,17 @@ static void SARKeyEngine(SAR_KEY_FUNC_PROTOTYPE)
 		    core_ptr->recorder, opt->event_sounds,
 		    SAR_IS_EAR_IN_COCKPIT(scene)
 		);
+                /* turn on engine sound */
+                if (used_to_be_engine_sound == True)
+                    opt->engine_sounds = True;
+                SARSceneSoundUpdate(
+                   core_ptr,
+                   opt->engine_sounds,
+                   opt->event_sounds,
+                   opt->voice_sounds,
+                   opt->music
+                 );
+
 	    }
 	}
 }
