@@ -1,3 +1,19 @@
+/**********************************************************************
+*   This file is part of Search and Rescue II (SaR2).                 *
+*                                                                     *
+*   SaR2 is free software: you can redistribute it and/or modify      *
+*   it under the terms of the GNU General Public License v.2 as       *
+*   published by the Free Software Foundation.                        *
+*                                                                     *
+*   SaR2 is distributed in the hope that it will be useful, but       *
+*   WITHOUT ANY WARRANTY; without even the implied warranty of        *
+*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See          *
+*   the GNU General Public License for more details.                  *
+*                                                                     *
+*   You should have received a copy of the GNU General Public License *
+*   along with SaR2.  If not, see <http://www.gnu.org/licenses/>.     *
+***********************************************************************/
+
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -2345,13 +2361,8 @@ elif defined(PROG_LANGUAGE_FRENCH)
 	{
 	    spin = SAR_MENU_SPIN(menu->object[spin_num]);
 	    spin->allow_warp = False;
-#ifdef JS_SUPPORT
 	    SARMenuSpinAddValue(menu, spin_num, "Standard");
 	    SARMenuSpinAddValue(menu, spin_num, "USB");
-#else
-	    SARMenuSpinAddValue(menu, spin_num, "No support");
-	    SARMenuObjectSetSensitive(display, menu, spin_num, False, False);
-#endif  /* JS_SUPPORT */
 	}
 
 	/* First joystick (js0) axis roles */
@@ -2364,7 +2375,6 @@ elif defined(PROG_LANGUAGE_FRENCH)
 	{
 	    spin = SAR_MENU_SPIN(menu->object[spin_num]);
 	    spin->allow_warp = False;
-#ifdef JS_SUPPORT
 	    SARMenuSpinAddValue(menu, spin_num, "Off");
 	    SARMenuSpinAddValue(menu, spin_num, "2D");
 	    SARMenuSpinAddValue(menu, spin_num, "2D with throttle");
@@ -2375,10 +2385,6 @@ elif defined(PROG_LANGUAGE_FRENCH)
 	    SARMenuSpinAddValue(menu, spin_num, "3D with hat");
 	    SARMenuSpinAddValue(menu, spin_num, "3D with throttle & hat");
 	    SARMenuSpinAddValue(menu, spin_num, "As throttle & rudder");
-#else
-	    SARMenuSpinAddValue(menu, spin_num, "No support");
-	    SARMenuObjectSetSensitive(display, menu, spin_num, False, False);
-#endif	/* JS_SUPPORT */
 	}
 
 	/* Second joystick (js1) connection type */
@@ -2391,13 +2397,8 @@ elif defined(PROG_LANGUAGE_FRENCH)
 	{
 	    spin = SAR_MENU_SPIN(menu->object[spin_num]);
 	    spin->allow_warp = False;
-#ifdef JS_SUPPORT
 	    SARMenuSpinAddValue(menu, spin_num, "Standard");
 	    SARMenuSpinAddValue(menu, spin_num, "USB");
-#else
-	    SARMenuSpinAddValue(menu, spin_num, "No support");
-	    SARMenuObjectSetSensitive(display, menu, spin_num, False, False);
-#endif  /* JS_SUPPORT */
 	}
 
 	/* Second joystick (js1) axis roles */
@@ -2410,7 +2411,6 @@ elif defined(PROG_LANGUAGE_FRENCH)
 	{
 	    spin = SAR_MENU_SPIN(menu->object[spin_num]);
 	    spin->allow_warp = False;
-#ifdef JS_SUPPORT
 	    SARMenuSpinAddValue(menu, spin_num, "Off");
 	    SARMenuSpinAddValue(menu, spin_num, "2D");
 	    SARMenuSpinAddValue(menu, spin_num, "2D with throttle");
@@ -2421,10 +2421,7 @@ elif defined(PROG_LANGUAGE_FRENCH)
 	    SARMenuSpinAddValue(menu, spin_num, "3D with hat");
 	    SARMenuSpinAddValue(menu, spin_num, "3D with throttle & hat");
 	    SARMenuSpinAddValue(menu, spin_num, "As throttle & rudder");
-#else
-	    SARMenuSpinAddValue(menu, spin_num, "No support");
-	    SARMenuObjectSetSensitive(display, menu, spin_num, False, False);
-#endif	/* JS_SUPPORT */
+
 	}
 
 	/* Joystick Priority Spin */
@@ -2437,24 +2434,15 @@ elif defined(PROG_LANGUAGE_FRENCH)
 	{
 	    spin = SAR_MENU_SPIN(menu->object[spin_num]);
 	    spin->allow_warp = False;
-#ifdef JS_SUPPORT
 	    SARMenuSpinAddValue(menu, spin_num, "Background");
 	    SARMenuSpinAddValue(menu, spin_num, "Foreground");
 	    SARMenuSpinAddValue(menu, spin_num, "Preempt");
-#else
-	    SARMenuSpinAddValue(menu, spin_num, "No support");
-	    SARMenuObjectSetSensitive(display, menu, spin_num, False, False);
-#endif	/* JS_SUPPORT */
 	}
 
 	/* Test Joystick Button */
 	btn_num = SARMenuBuildStandardButton(
 	    core_ptr, menu, 0.75f, 0.74f, btn_width_std, btn_height_std,
-#if defined(JS_SUPPORT)
 	    True,
-#else
-	    False,
-#endif
 	    "Test...", SAR_MENU_ID_GOTO_OPTIONS_CONTROLLER_TEST
 	);
 
@@ -2485,18 +2473,13 @@ elif defined(PROG_LANGUAGE_FRENCH)
 	/* Joystick Button Mapping Button */
 	btn_num = SARMenuBuildStandardButton(
 	    core_ptr, menu, 0.75f, 0.92f, btn_width_std, btn_height_std,
-#if defined(JS_SUPPORT)
 	    True,
-#else
-	    False,
-#endif
 	    "Buttons", SAR_MENU_ID_GOTO_OPTIONS_CONTROLLER_JS_BTN
 	);
 
 
 	/* ****************************************************** */
 	/* Menu: Options->Controller->Buttons */
-#ifdef JS_SUPPORT
 	img_path = SARMenuBuildGetFullPath(SAR_DEF_MENU_BGIMG_STANDARD_FILE);
 	menu = SARMenuNew(
 	    SAR_MENU_TYPE_STANDARD,
@@ -2665,7 +2648,6 @@ to set button number"
 	    core_ptr, menu, 0.75f, 0.74f, btn_width_std, btn_height_std,
 	    True, "Test...", SAR_MENU_ID_GOTO_OPTIONS_CONTROLLER_TEST
 	);
-#endif	/* JS_SUPPORT */
 
 	/* Back Button */
 	SARMenuBuildStandardButton(
@@ -2694,7 +2676,6 @@ to set button number"
 
 	/* ****************************************************** */
 	/* Menu: Options->Controller->Test */
-#ifdef JS_SUPPORT
 	img_path = SARMenuBuildGetFullPath(SAR_DEF_MENU_BGIMG_STANDARD_FILE);
 	menu = SARMenuNew(
 	    SAR_MENU_TYPE_STANDARD,
@@ -2744,7 +2725,6 @@ to set button number"
 #endif
 	    , SAR_MENU_ID_GOTO_OPTIONS_CONTROLLER
 	);
-#endif  /* JS_SUPPORT */
 
 
 	/* ****************************************************** */
@@ -2883,6 +2863,8 @@ to set button number"
 	SARMenuSpinAddValue(menu, spin_num, "640x480");
 	SARMenuSpinAddValue(menu, spin_num, "800x600");
 	SARMenuSpinAddValue(menu, spin_num, "1024x768");
+	SARMenuSpinAddValue(menu, spin_num, "1280x768");
+	SARMenuSpinAddValue(menu, spin_num, "1366x768");
 
 	/* Fullscreen Switch */
 	SARMenuBuildStandardSwitch(
@@ -3004,15 +2986,10 @@ to set button number"
 	{
 	    spin = SAR_MENU_SPIN(menu->object[spin_num]);
 	    spin->allow_warp = False;
-#if defined(HAVE_Y2) || defined(HAVE_SDL_MIXER)
 	    SARMenuSpinAddValue(menu, spin_num, "Off");
 	    SARMenuSpinAddValue(menu, spin_num, "Events");
 	    SARMenuSpinAddValue(menu, spin_num, "Events and Engine");
 	    SARMenuSpinAddValue(menu, spin_num, "Events, Engine, and Voice");
-#else
-	    SARMenuSpinAddValue(menu, spin_num, "No support");
-	    SARMenuObjectSetSensitive(display, menu, spin_num, False, False);
-#endif
 	}
 
 	/* Sound Priority Spin */
@@ -3025,14 +3002,9 @@ to set button number"
 	{
 	    spin = SAR_MENU_SPIN(menu->object[spin_num]);
 	    spin->allow_warp = False;
-#if defined(HAVE_Y2) || defined(HAVE_SDL_MIXER)
 	    SARMenuSpinAddValue(menu, spin_num, "Background");
 	    SARMenuSpinAddValue(menu, spin_num, "Foreground");
 	    SARMenuSpinAddValue(menu, spin_num, "Preempt");
-#else
-	    SARMenuSpinAddValue(menu, spin_num, "No support");
-	    SARMenuObjectSetSensitive(display, menu, spin_num, False, False);
-#endif
 	}
 
 	/* Music Switch */
@@ -3044,14 +3016,6 @@ to set button number"
 	    False, SAR_MENU_ID_OPT_MUSIC,
 	    SARMenuOptionsSwitchCB
 	);
-	if(switch_num > -1)
-	{
-#if defined(HAVE_Y2) || defined(HAVE_SDL_MIXER)
-
-#else
-	    SARMenuObjectSetSensitive(display, menu, switch_num, False, False);
-#endif
-	}
 
 	/* Volume Sliders */
 #ifdef __MSW__
@@ -3066,7 +3030,6 @@ to set button number"
 	);
 	if(slider_num > -1)
 	{
-#if defined(HAVE_Y2) || defined(HAVE_SDL_MIXER)
 	    SARMenuSliderSetValueBounds(
 		display, menu, slider_num,
 		0.0f, 1.0f, False
@@ -3075,12 +3038,6 @@ to set button number"
 		display, menu, slider_num,
 		0.0f, False
 	    );
-#else
-	    SARMenuObjectSetSensitive(
-		display, menu, slider_num,
-		False, False
-	    );
-#endif
 	}
 
 	/* Music Volume Slider */
