@@ -844,14 +844,17 @@ printf(
 	    }
 
 	    /* Play splash or explosion sound */
-	    if(over_water)
-	    {
-		DO_EFFECTS_SPLASH_AIRCRAFT
-	    }
-	    else
-	    {
-		DO_EFFECTS_CRASH_GROUND
-	    }
+            // only play crash sound the first time
+            if (crash_cause != 5) {  
+  	      if(over_water)
+	      {
+	  	  DO_EFFECTS_SPLASH_AIRCRAFT
+	      }
+	      else
+	      {
+		  DO_EFFECTS_CRASH_GROUND
+	      }
+            }   // end of crashed for the first time
 
 	    /* Call mission destroy notify instead of mission land
 	     * notify, to let mission know this object has crashed
