@@ -2243,10 +2243,18 @@ void SARSimSmokeSpawn(
 		/* Set initial velocity to drift upwards */
 /* TODO need to apply wind and other variables to drift velocity */
 		pos = &u->vel;
+                /*
+                This way smoke goes up, we want some variation.
 		pos->x = 0.0f;
 		pos->y = 0.0f;
 		pos->z = 4.0f;
-
+                */
+               /* Smoke moves up at random speed and with a small but random
+                   horizontal speeds */
+                pos->x = 2 * (rand()/(float)(RAND_MAX) - 0.5);
+                pos->y = 2 * (rand()/(float)(RAND_MAX) - 0.5);
+                pos->z = 2 * rand()/(float)(RAND_MAX) + 3;
+               
 		/* Apply offset to initial position */
 		pos = &u->pos;
 		pos->x += obj_smoke_ptr->respawn_offset.x;
@@ -2843,6 +2851,12 @@ int SARSimBoardObject(
 	if(passengers_mass != NULL)
 	    *passengers_mass = MAX(*passengers_mass, 0.0f) + src_mass;
 
+        /* If a mission is active then call the mission passengers
+           enter notify callback
+        */
+        if (core_ptr->mission)
+           SARMissionPassengersEnterNotify(core_ptr, tar_obj_ptr, 1);
+
 	/* Delete the source object */
 	SARObjDelete(
 	    core_ptr,
