@@ -101,9 +101,10 @@ void V3DTextureDestroy(v3d_texture_ref_struct *t);
   GL_NEAREST						\
  );							\
 }
+#else
+#ifndef NEW_GRAPHICS
+#define NEW_GRAPHICS
 #endif
-
-#ifdef NEW_GRAPHICS
 #define TEXTUREIO_TEX_OPTIONS_2D                        \
 {                                                       \
  glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_REPEAT); \
